<?php
/**
 * KFM - Kae's File Manager - database maintenance
 *
 * @category None
 * @package  None
 * @author   Benjamin ter Kuile <bterkuile@gmail.com>
 * @license  docs/license.txt for licensing
 * @link     http://kfm.verens.com/
 */
require_once 'initialise.php';

//////////////////// Breeze Website Builder modification ///////////////////////////
if ((!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off') || $_SERVER['SERVER_PORT'] == 443)
	$http = "https://";
else
	$http = "http://";
//////////////////// Breeze Website Builder modification ///////////////////////////
?>
<!DOCTYPE html>
<html>
<head>
<title>KFM-maintenance</title>
<script type="text/javascript" src="<?php echo $http; ?>ajax.googleapis.com/ajax/libs/jquery/1.4.2/jquery.min.js"></script>
<script type="text/javascript">
	var $j = jQuery.noConflict();
	$j(document).ready(function(){
	});
</script>
<style type="text/css">
body{
	background-color:#eeeeee;
}
</style>
</head>
<body>
<div id="maintenance_messages">
<?php
//Ghost file deletion
$kfmdb->query('DELETE FROM '.KFM_DB_PREFIX.'_files WHERE directory=0');
?>
<p>Maintenance done. <a href="index.php">Return to the filemanager</a></p>
</div>
<div id="maintenance_complete_html" style="display:none;">
<h2>Maintenance complete</h2>
</div>
</body>
</html>
